const atombundle = document.getElementById("atombundle");

function parseAtomList(atomdoc) {
	// Parses a list of Atom feeds.
	// In: Atom XML feeds document.
	// Out: An array of objects. Each object has .title, .post, and .feed.
	//	.title is the title of the blog.
	//	.post is the URL to use for posting to the blog.
	//	.feed is the URL to get data from the blog.
	if (atomdoc.documentElement.tagName != "feed") throw atombundle.getString("NotFeed");
	
	var _blogarray = [];
	var _blogs = atomdoc.documentElement.getElementsByTagName("link");
	for (i = 0; i < _blogs.length; i++) {
		if (_blogs[i].getAttribute("rel") == "service.post") {
			var _blogdetail = new Object();
			_blogdetail["title"] = _blogs[i].getAttribute("title");
			_blogdetail["post"] = _blogs[i].getAttribute("href");
			for (z = 0; z < _blogs.length; z++) {
				var _blog = _blogs[z];
				if ((_blog.getAttribute("rel") == "service.feed") && (_blog.getAttribute("title") == _blogdetail["title"])) {
					_blogdetail["feed"] = _blog.getAttribute("href");
					break;
				}
			}
			_blogarray.push(_blogdetail);
		}
	}
	return _blogarray;
}

function AtomPost() {
	var _atompost = document.implementation.createDocument("", "entry", null);
	//Setting the namespace via createDocument was giving me headaches. 
	_atompost.documentElement.setAttribute("xmlns", "http://purl.org/atom/ns#");
	
	_atompost.insertBefore(_atompost.createProcessingInstruction("xml", "version=\"1.0\" encoding=\"utf-8\" standalone=\"yes\""), _atompost.documentElement);
	
	var _generator = _atompost.documentElement.appendChild(_atompost.createElement("generator"));
	_generator.setAttribute("url", "http://deepestsender.mozdev.org");
	_generator.appendChild(_atompost.createTextNode("Deepest Sender"));
	
	this.atom = _atompost;
}

AtomPost.prototype.addTitle = function(_title) {
	var _titlenode = this.atom.documentElement.appendChild(this.atom.createElement("title"));
	_titlenode.setAttribute("mode", "escaped");
	_titlenode.setAttribute("type", "text/plain");
	_titlenode.appendChild(this.atom.createTextNode(_title));
	this.atom.normalize();
}

AtomPost.prototype.setDate = function(_date) {
	var issued = this.atom.documentElement.appendChild(this.atom.createElement("issued"));
	var iso8601 = _date.getUTCFullYear() + "-" + ZeroFix(_date.getUTCMonth() + 1) + "-" + ZeroFix(_date.getUTCDate()) + "T" + ZeroFix(_date.getUTCHours()) + ":" + ZeroFix(_date.getUTCMinutes()) + ":" + ZeroFix(_date.getUTCSeconds()) + "Z";
	issued.appendChild(this.atom.createTextNode(iso8601));
}

AtomPost.prototype.addPost = function(_post) {
	var _content = this.atom.documentElement.appendChild(this.atom.createElement("content"));
	_content.setAttribute("type", "application/xhtml+xml");
	
	var _domparser = new DOMParser();
	// You need to create an entire XHTML document and feed the post into it, then parse it, otherwise it'll give errors about entities
	//	like nonbreaking spaces and stuff.
	
	var _messagestring = "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\" \"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">\n" +
				"<html xmlns=\"http://www.w3.org/1999/xhtml\"><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />\n" +
				"</head><body id=\"postbody\"><div xmlns=\"http://www.w3.org/1999/xhtml\">" + _post + "</div></body></html>";
	
	var _message = _domparser.parseFromString(_messagestring, "application/xhtml+xml");
	
	if (_message.documentElement.tagName == "parsererror") {
		throw atombundle.getString("XMLNotWellFormed");
	}
	
	_content.appendChild(this.atom.importNode(_message.getElementById("postbody").firstChild, true));
	// All the normalisation is to get around a bug in Gecko treating text nodes over 4k as multiple nodes.
	this.atom.normalize();
}

AtomPost.prototype.addCustomTag = function(_tagname, _namespace, _contents, _attributes) {
	// This needs work so you can add non-text content and extra nodes.
	var _customtag = this.atom.documentElement.appendChild(this.atom.createElement(_tagname));
	_customtag.setAttribute("xmlns", _namespace);
	if (_attributes) {
		for (z in _attributes) {
			_customtag.setAttribute(z, _attributes[z]);
		}
	}
	if (_contents != null) _customtag.appendChild(this.atom.createTextNode(_contents));
	this.atom.normalize();
}

AtomPost.prototype.addLinkURL = function(_link, _title) {
	var _linktag = this.atom.documentElement.appendChild(this.atom.createElement("link"));
	_linktag.setAttribute("rel", "related");
	_linktag.setAttribute("type", "text/html");
	if (_title) _linktag.setAttribute("title", _title);
	_linktag.setAttribute("href", _link);
	this.atom.normalize();
}

